@@ -21,9 +21,9 @@ class States;
 
 class DFARow: private FlexTypes
 {
-    typedef std::pair<size_t, size_t> Pair;
-    typedef std::set<size_t> StateSet;
-    typedef std::vector<StateSet> StateSetVector;   // a set of states per
+    using Pair = std::pair<size_t, size_t>;
+    using StateSet = std::set<size_t>;
+    using StateSetVector = std::vector<StateSet>;   // a set of states per
                                                     // input symbol
 
     FBB::LinearMap<size_t, size_t> d_map;   // Relate input symbols (key) 
@@ -47,7 +47,7 @@ class DFARow: private FlexTypes
     std::vector<bool> *d_usedRanges;
 
     public:
-        typedef FBB::LinearMap<size_t, size_t>::value_type MapValue;
+        using MapValue = FBB::LinearMap<size_t, size_t>::value_type;
 
         DFARow() = default;
 
