@@ -10,12 +10,14 @@ void Generator::classHead(ostream &out) const
         "class " << name << ": public " << name << "Base\n"
         "{\n"
         "    public:\n"
-        "        explicit " << name << "(std::istream &in = std::cin,\n"
-        "                                std::ostream &out = std::cout);\n";
+        "        explicit " << name << "(std::istream &in = std::cin, "
+                                        "std::ostream &out = std::cout, "
+                                        "bool keepCwd = true);\n";
 
     if (not d_options.interactive())
         out << 
             "\n"
             "        " << name << "(std::string const &infile, "
-                                            "std::string const &outfile);\n";
+                                   "std::string const &outfile, "
+                                   "bool keepCwd = true);\n";
 }
