@@ -3,7 +3,7 @@
 void Generator::lop3(ostream &out) const
 {
     out <<
-"inline void " << d_baseclassScope << R"(lop3__() // catch-all handler
+"inline void " << d_baseclassScope << R"(lop3_() // catch-all handler
 {
     d_lopIter = --d_lopTail;                // increase the tail, try again
 )";
@@ -11,9 +11,9 @@ void Generator::lop3(ostream &out) const
     if (d_debug)
         out <<
 R"(
-    if (s_debug__)
-        s_out__ << "lop3__: trying to match tail `" << 
-               std::string(d_lopIter, d_lopEnd) << "'\n" << dflush__;
+    if (s_debug_)
+        s_out_ << "lop3_: trying to match tail `" << 
+               std::string(d_lopIter, d_lopEnd) << "'\n" << dflush_;
 )";
 
     out << 
