@@ -1,6 +1,6 @@
 #include "generator.ih"
 
-void Generator::ruleAction(Block const &block, ostream &out, size_t &idx) 
+void Generator::ruleAction(Block const &block, ostream &out, size_t idx) 
                                                                         const
 {
     if (block.orAction())
@@ -14,11 +14,14 @@ void Generator::ruleAction(Block const &block, ostream &out, size_t &idx)
         if (d_lineDirectives)
             out << "#line " << block.lineNr()  << 
                                " \"" << block.filename() << "\"\n";
+
+        istringstream actions(block.str());
+        string line;
+        while (getline(actions, line))
+            out << setw(12) << ' ' << line << '\n';
+
         out << 
-            "            " << block.str() << "\n"
             "        }\n"
             "        break;\n";
     }
-
-    ++idx;
 }
