@@ -37,12 +37,14 @@ class Options: private FlexTypes
     std::string d_lexSource;
 
     std::string d_baseClassSkeleton;
+    std::string d_baseClassPreinclude;
     std::string d_className;
     std::string d_classSkeleton;
     std::string d_constructionPath;
     std::string d_filenames;
     std::string d_implementationSkeleton;
     std::string d_inputImplementation;
+    std::string d_inputInlinePath;
     std::string d_inputInterfacePath;
     std::string d_lexFunctionName;
     std::string d_lexSkeleton;
@@ -125,12 +127,14 @@ class Options: private FlexTypes
 
         std::string const &lexSourcePath() const;
 
+        std::string const &baseclassPreinclude() const;
         std::string const &baseclassSkeleton() const;
         std::string const &classSkeleton() const;
         std::string const &className() const;
         std::string const &filenames() const;
         std::string const &implementationSkeleton() const;
         std::string const &inputImplementation() const;
+        std::string const &inputInline() const;
         std::string const &inputInterface() const;
         std::string const &lexFunctionName() const;
         std::string const &lexSkeleton() const;
@@ -142,6 +146,7 @@ class Options: private FlexTypes
         std::string implementationHeaderName() const;
 
         void setBaseClassHeader(TextType textType);
+        void setBaseClassPreinclude(TextType textType);
         void setClassHeader(TextType textType);
         void setClassName(TextType textType);
         void setCaseInsensitive();
@@ -149,6 +154,7 @@ class Options: private FlexTypes
         void setFilenames(TextType textType);
         void setImplementationHeader(TextType textType);
         void setInputImplementationPath(TextType textType);
+        void setInputInlinePath(TextType textType);
         void setInputInterfacePath(TextType textType);
         void setInteractive();
         void setLexFunctionName(TextType textType);
@@ -234,6 +240,11 @@ inline std::string const &Options::constructionPath() const
     return d_constructionPath;
 }
 
+inline std::string const &Options::inputInline() const
+{
+    return d_inputInlinePath;
+}
+
 inline std::string const &Options::inputInterface() const
 {
     return d_inputInterfacePath;
@@ -249,6 +260,11 @@ inline std::string const &Options::inputImplementation() const
     return d_inputImplementation;
 }
 
+inline std::string const &Options::baseclassPreinclude() const
+{
+    return d_baseClassPreinclude;
+}
+
 inline std::string const &Options::baseclassSkeleton() const
 {
     return d_baseClassSkeleton;
@@ -334,12 +350,16 @@ inline void Options::setNameSpace(TextType textType)
     assign(textType, &d_nameSpace, FILENAME, "namespace");
 }
 
-
 inline void Options::setInputImplementationPath(TextType textType)
 {
     assign(textType, &d_inputImplementation, PATHNAME, "input-implementation");
 }
    
+inline void Options::setInputInlinePath(TextType textType)
+{
+    assign(textType, &d_inputInlinePath, PATHNAME, "input-inline");
+}
+   
 inline void Options::setInputInterfacePath(TextType textType)
 {
     assign(textType, &d_inputInterfacePath, PATHNAME, "input-interface");
@@ -350,6 +370,11 @@ inline void Options::setBaseClassHeader(TextType textType)
     assign(textType, &d_baseClassHeader, FILENAME, baseclassHeaderSpec());
 }
    
+inline void Options::setBaseClassPreinclude(TextType textType)
+{
+    assign(textType, &d_baseClassPreinclude, PATHNAME, 
+                                                    "baseclass-preinclude");
+}
 inline void Options::setClassHeader(TextType textType)
 {
     assign(textType, &d_classHeader, FILENAME, classHeaderSpec());
