@@ -22,18 +22,27 @@ Pattern Parser::lookahead(Pattern const &left, Pattern const &right)
     d_doError = true;
     d_usesLOP = true;
 
-    setFlags(left.begin(), State::PRE);
-    setFlags(right.begin(), State::POST);
+    Pattern ret;
+    if (right.canBeEmpty(d_states))
+    {
+        wmsg << "null-matching trailing context is ignored" << endl;
+        ret = left;    
+    }
+    else if (right.fixedLength())            // fixed tail lop rule
+    {
+        d_rules.setFixedTailLOPrules();
+        ret = Pattern(d_states, right.length(), left, right);
+    }
+    else
+    {
+        d_rules.setVariableTailLOPrules();
+        ret = Pattern(d_states, left, right,  d_nLOPstartConditions);
+        d_nLOPstartConditions += 2;
+        d_scanner.needCatchAll();
+    }
 
-    d_states[right.begin()].setFlag(State::ACCEPT);
-
-    return Pattern::concatenate(d_states, left, right);
+    return ret;
 }
 
 
 
-
-
-
-
-
