@@ -10,7 +10,7 @@ Parser::Parser(Rules &rules, States &states)
     d_rules(rules),
     d_states(states)
 {
-    d_options.setParserInfo(d_matched, d_rawStringContents);
+    d_options.setParserInfo(d_matched, d_rawStringContent);
     s_ignoreToken = token_();      // set by ParserBase to _UNDETERMINED
 //    setDebug(d_options.debug());    // write debug code to the generated
                                     // lex.cc file 
