@@ -2,6 +2,6 @@
 
 Parser::TextType Parser::rawString()
 {
-    d_rawStringContents = d_scanner.rawStringContents();
+    d_rawStringContent = d_scanner.rawStringContent();
     return TextType::RAWSTRING;
 }
