@@ -2,8 +2,10 @@
 
 bool Pattern::canBeEmpty(States const &states) const
 {
+    set<size_t> indices;
+
     return 
         (fixedLength() && length() == 0)
         or
-        empty(states, d_pair.first);
+        empty(indices, states, d_pair.first);
 }
