@@ -1,3 +1,4 @@
+//#define XERR
 #include "pattern.ih"
 
 Pattern Pattern::interval(States &states, Pattern &regex,
@@ -8,11 +9,32 @@ Pattern Pattern::interval(States &states, Pattern &regex,
     size_t lower = interval.lower();
     size_t upper = interval.upper();
 
-    if (lower == 0 && upper == max<size_t>())
-        ret = star(states, regex);
+    if (lower == 0)
+    {
+        switch (upper)
+        {
+            case 0:
+                wmsg << "ignoring regex{0, 0}" << endl;
+            return regex;
 
-    else if (lower == 0 && upper == 1)
-        ret = questionMark(states, regex);
+            case 1:
+                ret = questionMark(states, regex);
+            break;
+
+            case numeric_limits<size_t>::max():
+                ret = star(states, regex);
+            break;
+
+            default:        // {0, x}, with 1 < x < size_t::max
+            {
+                Interval oneUp(1, upper);
+                
+                Pattern tmp = Pattern::interval(states, regex, oneUp);
+                ret = questionMark(states, tmp);
+            }                                
+            break;
+        }
+    }
 
     else if (lower == 1 && upper == max<size_t>())
         ret = plus(states, regex);
@@ -20,6 +42,7 @@ Pattern Pattern::interval(States &states, Pattern &regex,
     else if (lower <=  upper)
     {
         ret = copy(states, regex, lower, upper);
+
         if (lower == upper && regex.fixedLength())
             ret.d_length = lower * regex.d_length;
     }
@@ -31,6 +54,7 @@ Pattern Pattern::interval(States &states, Pattern &regex,
 
         ret = Pattern(pair);
     }
+
     return ret;
 }
 
