@@ -16,9 +16,9 @@ class States;
 
 class Pattern: private FlexTypes
 {
-        typedef FBB::LinearMap<size_t, size_t>  Map;
-        typedef std::pair<size_t, size_t>           Pair;
-        typedef std::vector<Pair>                   PairVector;
+    using Map = FBB::LinearMap<size_t, size_t>;
+    using Pair = std::pair<size_t, size_t>;
+    using PairVector = std::vector<Pair>;
 
     struct LopData;
     std::shared_ptr<LopData> d_lopData;
