@@ -10,6 +10,7 @@ struct Tokens
         INCL_START_CONDITION,
         SECTION_DELIMITER,
         BASECLASSHEADER,
+        BASECLASSPREINCLUDE,
         CASEINSENSITIVE,
         CLASSHEADER,
         CLASSNAME,
@@ -17,6 +18,7 @@ struct Tokens
         FILENAMES,
         IMPLEMENTATIONHEADER,
         INPUTIMPLEMENTATION,
+        INPUTINLINE,
         INPUTINTERFACE,
         INTERACTIVE,
         LEXFUNCTIONNAME,
