@@ -61,8 +61,8 @@ struct StartConditions
         void addSC(std::string const &name); // adds name to a set of SCs
         void activate(size_t scIndex);          // activates just this SC
 
-        typedef FBB::LinearMap<std::string, StartCondition>::const_iterator
-                                                            const_iterator;
+        using const_iterator = 
+           FBB::LinearMap<std::string, StartCondition>::const_iterator;
 
         const_iterator begin() const;
         const_iterator end() const;
