@@ -18,7 +18,7 @@ class States: private FlexTypes
     std::vector<size_t> d_free;
 
     public:
-        typedef std::pair<size_t, size_t> Pair;
+        using Pair = std::pair<size_t, size_t>;
 
         States();
         State &operator[](size_t idx);
