@@ -9,6 +9,8 @@ Where:
   [options] - zero or more optional arguments, where [options] are:
    --baseclass-header=<filename> (-b):
            filename for the base class definition.
+   --baseclass-preinclude=<path> (-H):
+           location of the baseclass preinclude file.
    --baseclass-skeleton=<path> (-B):
            location of the baseclass header skeleton.
    --case-insensitive:
